li[class|="customize-control-consultstreet-"] {
	.wp-picker-container {

		.wp-color-result.button {
			width: 100%;
			max-width: 255px;
			height: 30px;
			margin: 0 6px 6px 0;
			padding: 0 0 0 30px;
			font-size: 11px;
			box-shadow: none;
			border: 1px solid rgba(0, 0, 0, 0.1);
		}

		.wp-color-result-text {
			background: rgba(0, 0, 0, 0.1);
			border-radius: 0 2px 2px 0;
			border-left: 1px solid rgba(0, 0, 0, 0.06);
			color: $c-white;
			display: flex;
			justify-content: center;
			align-items: center;
			height: 100%;
		}

		span.color-alpha {
			width: 30px;
			height: 24px;
			position: absolute;
			top: 0;
			left: 0;
			border-top-left-radius: 2px;
			border-bottom-left-radius: 2px;
		}
	}
}
