$c-background: rgba(0, 0, 0, 0.15);
$c-background-hover: rgba(0, 0, 0, 0.2);
$c-primary: #13a1dc;
$c-white: #fff;
$c-shadow: rgba(0, 0, 0, 0.3);
$c-sortable-bd: #333;
$c-sortable-ds: #aaa;
$c-bg-label: rgba(255, 255, 255, 0.7);
$c-bg-checked: rgba(0, 0, 0, 0.25);
$c-bg-switch: #b4b9be;
$c-switch-ds: #777;
$c-light-bg: #e4f2fc;
