.in-sub-panel #customize-theme-controls .customize-pane-child.current-panel-parent,
#customize-theme-controls .customize-pane-child.current-section-parent {
	-webkit-transform: translateX(-100%);
	-ms-transform: translateX(-100%);
	transform: translateX(-100%);
}

/* Nested Customizer Section CSS */
#customize-controls .control-section.control-section-consultstreet_section .accordion-section-title {
	color: #555d66;
	background-color: #fff;
	border-bottom: 1px solid #ddd;
	border-left: 4px solid #fff;
	-webkit-transition: .15s color ease-in-out, .15s background-color ease-in-out, .15s border-color ease-in-out;
	transition: .15s color ease-in-out, .15s background-color ease-in-out, .15s border-color ease-in-out;
}

#customize-controls .control-section.control-section-consultstreet_section .accordion-section-title:after {
	color: #a0a5aa;
}

#customize-controls .control-section.control-section-consultstreet_section .accordion-section-title:hover,
#customize-controls .control-section.control-section-consultstreet_section .accordion-section-title:focus {
	color: #3858e9;
	background: #f3f3f5;
	border-left-color: #3858e9;
}

#customize-controls .control-section.control-section-consultstreet_section .accordion-section-title:hover:after {
	color: #3858e9;
}

#customize-controls .control-section-consultstreet_section .accordion-section {
	margin-left: -12px;
	margin-right: -12px;
}

#customize-controls .customize-control-consultstreet-editor .wp-editor-tools .wp-editor-container textarea {
	width: 100%;
}
